@@ -10,12 +10,12 @@ use MarpaX::Languages::C::AST;
 use Config;
 use Carp qw/croak/;
 use Data::Dumper;
-use IPC::Cmd qw/run/;
+use Try::Tiny;
+use IO::CaptureOutput qw/capture_exec/;
 use File::Temp qw/tempfile/;
 use IO::File;
 use Scalar::Util qw/blessed reftype/;
 use Regexp::Common;
-use String::ShellQuote qw/shell_quote_best_effort/;  # Not for Win32, but passes everywhere, so ok to use it like that
 use Log::Any qw/$log/;
 use constant {
     LEXEME_POSITION_INDEX => 0,
@@ -33,13 +33,11 @@ use XML::LibXSLT;
 use constant { TYPE => 0, QUALIFIER => 1, IDENTIFIER => 2, OTHER => 3, SKIPPED => 4, DECLARATOR => 5 };
 our @type2String = qw/TYPE QUALIFIER IDENTIFIER OTHER SKIPPED DECLARATOR/;
 
-our $HAVE_SYS__INFO = eval 'use Sys::Info; 1' || 0;
-our $HAVE_Win32__ShellQuote = _is_windows() ? (eval 'use Win32::ShellQuote qw/quote_native/; 1' || 0) : 0;
 our $RESAMELINE = qr/(?:[ \t\v\f])*/;                        # i.e. WS* without \n
 our $REDEFINE = qr/^${RESAMELINE}#${RESAMELINE}define${RESAMELINE}((\w+)(?>[^\n\\]*)(?>\\.[^\n\\]*)*)/ms; # dot-matches-all mode, keeping ^ meaningful
 our $BALANCEDPARENS = qr/$RE{balanced}{-parens=>'()'}{-keep}/;
 
-our $VERSION = '0.45'; # VERSION
+our $VERSION = '0.46'; # VERSION
 
 
 # ----------------------------------------------------------------------------------------
@@ -70,7 +68,6 @@ sub new {
               _astConfig        => \%astConfig,
              };
 
-
   #
   # For anonymous enums or structs, so that their names do not clash
   #
@@ -87,8 +84,8 @@ sub new {
     # physically on disk and still visible for our process
     #
     $self->{_tmpfh} = IO::File->new($filename, 'r') || croak "Cannot open $filename, $!";
-    print($self->{_content2fh}, $opts{content});
-    close($self->{_content2fh}) || warn "Cannot close $self->{_content2fh}, $!";
+    $self->{_content2fh}->print($opts{content});
+    $self->{_content2fh}->close() || warn "Cannot close $self->{_content2fh}, $!";
     $self->{_content} = $opts{content};
   } else {
     if (! exists($opts{filename}) || ! defined($opts{filename})) {
@@ -133,7 +130,7 @@ sub new {
   #
   # Delete what is left
   #
-  delete($self->{_content});
+  # delete($self->{_content});
   delete($self->{_anonCount});
 
   return $self;
@@ -160,6 +157,15 @@ sub astToString {
 # ----------------------------------------------------------------------------------------
 
 
+sub content {
+  my $self = shift;
+
+  return $self->{_content};
+}
+
+# ----------------------------------------------------------------------------------------
+
+
 sub get {
   my ($self, $attribute) = @_;
 
@@ -360,46 +366,6 @@ sub cdecl {
 }
 
 
-# ----------------------------------------------------------------------------------------
-# Brutal copy of String::ShellQuote::quote_literal
-
-sub _quote_literal {
-    my ($text, $force) = @_;
-
-    # basic argument quoting.  uses backslashes and quotes to escape
-    # everything.
-    if (!$force && $text ne '' && $text !~ /[ \t\n\x0b"]/) {
-        # no quoting needed
-    }
-    else {
-        $text =~ s{(\\*)(?="|\z)}{$1$1}g;
-        $text =~ s{"}{\\"}g;
-        $text = qq{"$text"};
-    }
-
-    return $text;
-}
-
-# ----------------------------------------------------------------------------------------
-
-sub _is_windows {
-  my $rc;
-
-  if ($HAVE_SYS__INFO) {
-    my $info = Sys::Info->new;
-    my $os   = $info->os();
-    $rc = $os->is_windows;
-  } else {
-    if ($^O =~ /win32/i) {
-      $rc = 1;
-    } else {
-      $rc = 0;
-    }
-  }
-
-  return $rc;
-}
-
 # ----------------------------------------------------------------------------------------
 
 sub _init {
@@ -416,26 +382,31 @@ sub _init {
       # Remains the filename that we do ourself.
       # Two big categories: Win32, others
       #
-      my $quotedFilename;
-      my $cmd = "$self->{_cpprun} $self->{_cppflags} ";
-      if (_is_windows()) {
-        if ($HAVE_Win32__ShellQuote) {
-          $quotedFilename = quote_native($self->{_orig_filename});
-        } else {
-          $quotedFilename = _quote_literal($self->{_orig_filename}, 1);
+      my $cmd = "$self->{_cpprun} $self->{_cppflags} $self->{_orig_filename}";
+
+      my ($stdout, $stderr, $success, $exitCode );
+      my $executed = 0;
+      my $errorString = undef;
+      try {
+        ($stdout, $stderr, $success, $exitCode) = capture_exec($cmd);
+      } catch {
+        $errorString = $_;
+        return;
+      } finally {
+        if (! $@) {
+          $executed = 1;
         }
-      } else {
-        $quotedFilename = shell_quote_best_effort($self->{_orig_filename});
-      }
-      $cmd .= $quotedFilename;
+      };
 
-      my ($success, $error_code, undef, $stdout_bufp, $stderr_bufp) = run(command => $cmd);
-
-      if (! $success) {
-        croak join('', @{$stderr_bufp});
+      if (! $executed) {
+        if (defined($errorString)) {
+          croak "$cmd: $errorString";
+        } else {
+          croak "$cmd: failure (no error available)";
+        }
       }
 
-      $stdout_buf = join('',@{$stdout_bufp});
+      $stdout_buf = $stdout;
     } else {
       $log->debugf('Disabling cpp step');
       my $fh;
@@ -599,7 +570,8 @@ sub _xpath {
 
 # ----------------------------------------------------------------------------------------
 
-sub _xslt {
+
+sub xslt {
   my ($self, $wantedFilename) = @_;
 
   if (! defined($self->{_xslt}->{$wantedFilename})) {
@@ -703,7 +675,8 @@ sub _pushNodeString {
 
 # ----------------------------------------------------------------------------------------
 
-sub _fileOk {
+
+sub fileOk {
   my ($self, $file) = @_;
 
   my $rc = 0;
@@ -776,7 +749,7 @@ sub _pushNodeFile {
     $node->setAttribute('file', $file);
   }
 
-  return $self->_fileOk($file);
+  return $self->fileOk($file);
 }
 
 # ----------------------------------------------------------------------------------------
@@ -2130,7 +2103,7 @@ sub _lexemeCallback {
     $lexemeHashp->{value} =~ s/\n/\\n/g;
   }
 
-  if (defined($tmpHashp->{_currentFile}) && $self->_fileOk($tmpHashp->{_currentFile})) {
+  if (defined($tmpHashp->{_currentFile}) && $self->fileOk($tmpHashp->{_currentFile})) {
     if ($lexemeHashp->{name} eq 'STRING_LITERAL_UNIT') {
       #
       # ISO C permits WS at the end of a string literal, we remove it
@@ -2242,7 +2215,7 @@ sub c2cifce {
   $log->tracef('Calling transformation with parameters %s', \%params);
 
   my $ast = $self->ast();
-  my $langXslt = $self->_xslt($lang);
+  my $langXslt = $self->xslt($lang);
   my $transform = $langXslt->transform($ast, %params);
 
   return ($langXslt, $transform);
@@ -2265,7 +2238,7 @@ MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011::Scan - Scan C source
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 SYNOPSIS
 
@@ -2362,6 +2335,10 @@ AST of the preprocessed output. This is an XML::LibXML document.
 
 Stringified AST of the preprocessed output. This is an XML::LibXML document passed through its toString(1) in DOM mode, a Data::Dumper output if non-DOM mode.
 
+=head2 content($self)
+
+Original content.
+
 =head2 get($self, $attribute)
 
 C::Scan like method, that is a proxy to $self->$attribute. All methods described after can be used as attribute, for example: $self->get('strings'), or $self->get('includes').
@@ -2430,6 +2407,14 @@ All top-level declarations. This is a XML::LibXML::Document containing a list of
 
 Cdecl-like string of top-level declarations. Available only when asDOM option is atrue value. Returns a reference to an array.
 
+=head2 xslt($self, $wantedFilename)
+
+Compiles an XSLT, searching $wantedFilename in the $self's xsltDirectories if given, then in the shared directory provided with this package. Returns an XML::LibXSLT object instance.
+
+=head2 fileOk($self, $file)
+
+Returns a true or false value if the $file argument matches the original filter. Default filter is the file being analysed.
+
 =head2 c2cifce($self, $lang, %params)
 
 Applies the transformation $lang, with parameters %params, and returns an array composed of the XML::LibXSLT instance and the transformed new XML::LibXML::Document.
